camelot.camelot.view.plugins.richtexteditorplugin.DateEditorPlugin

Package camelot :: Package camelot :: Package view :: Package plugins :: Module richtexteditorplugin :: Class DateEditorPlugin |
[hide private]
[frames] | no frames]

# Class DateEditorPlugin

source code

Instance Methods | [hide private]
__init__(self, parent=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `CamelotEditorPlugin`: `createWidget`, `domXml`, `group`, `includeFile`, `initialize`, `isContainer`, `isInitialized`, `name`, `toolTip`, `whatsThis` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, parent=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)